@@ -7,3 +7,5 @@
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
 #undef HAVE_GMP2_INCLUDE_DIR
+#undef HAVE_WORDEXP
+#undef GETTEXT_PACKAGE
